@@ -1,15 +1,17 @@
 #!/usr/bin/perl
 
+use strict;
 use DBI;
+use Data::Dumper;
 
-$DATABASE='test';
-$HOST='localhost';
-$PORT=3306; $USER='root';
-$PASSWORD='';
+my $db='test';
+my $host='localhost';
+my $user='root';
+my $password='';
+my $i= 0;
 
-#DBI->trace(3);
-$dbh = DBI->connect("DBI:mysql:$DATABASE:$HOST:$PORT",
-		    "$USER", "$PASSWORD",
+my $dbh = DBI->connect("DBI:mysql:$db:$host",
+		    "$user", "$password",
 		  { PrintError => 0}) || die $DBI::errstr;
 
 # DROP TABLE IF EXISTS 
@@ -19,7 +21,8 @@ $dbh->do("CREATE TABLE users (id INT, name VARCHAR(32))") or print $DBI::errstr;
 
 my $sth= $dbh->prepare("INSERT INTO users VALUES (?, ?)");
 
-for $i(1 .. 20) {
+for $i(1 .. 20)
+{
   my @chars = grep !/[0O1Iil]/, 0..9, 'A'..'Z', 'a'..'z';
   my $random_chars = join '', map { $chars[rand @chars] } 0 .. 31;
 
@@ -31,24 +34,25 @@ $dbh->do("DROP PROCEDURE IF EXISTS users_proc") or print $DBI::errstr;
 $dbh->do("CREATE PROCEDURE users_proc() DETERMINISTIC 
 BEGIN 
   SELECT id, name FROM users;
+  SELECT name, id FROM users;
 END") or print $DBI::errstr;
 
 $sth = $dbh->prepare('call users_proc()') || 
  die $DBI::err.": ".$DBI::errstr;
 
- $sth->execute || die DBI::err.": ".$DBI::errstr; $rowset=0;
+ $sth->execute || die DBI::err.": ".$DBI::errstr;
  do {
-   print "\nRowset ".++$i."\n---------------------------------------\n\n";
-   foreach $colno (0..$sth->{NUM_OF_FIELDS}) {
-     print $sth->{NAME}->[$colno]."\t";
-   }
-   print "\n";
-   while (@row=$sth->fetchrow_array())  {
-     foreach $field (0..$#row) {
-       print $row[$field]."\t";
-     }
-     print "\n";
-   }
- } until (!$sth->more_results)
+  print "\nResult set ".++$i."\n---------------------------------------\n\n";
+  for my $colno (0..$sth->{NUM_OF_FIELDS}) {
+    print $sth->{NAME}->[$colno]."\t";
+  }
+  print "\n";
+  while (my $rowref=$sth->fetchrow_arrayref())  {
+    for my $field (0..$#$rowref) {
+      print $rowref->[$field]."\t";
+    }
+    print "\n";
+  }
+ } while ($sth->more_results())
 
 
